#!/usr/bin/python
# -*- coding: UTF-8 -*-
# 描述:
# @author: dejian.liu
# @date:  2022-08-10 14:39

# 阿里云OSS配置
ALI_OSS_KEY = 'xxxxxxxx'
ALI_OSS_SECRET = 'yyyyyyyyyyy'
ALI_OSS_BUCKET = 'backet'
ALI_OSS_ENDPOINT = 'dev.xx.com'

# nacos 统一配置中心
NACOS_SERVER = "http://192.168.0.12:8848"
NACOS_USER_NAME = "nacos"
NACOS_PASSWORD = "nacos"
NACOS_NAMESPACE = "dev"
NACOS_ALG_WEB_GROUP = "DEFAULT_GROUP"
NACOS_ALG_WEB_DATA_ID = "common"
NACOS_SERVER_NAME = "ldj-common"

# xxl-job配置
XXL_JOB_SERVER = "http://192.168.0.123:8080/xxl-job-admin/api/"
XXL_JOB_HOST = "192.168.0.88"
XXL_JOB_EXECUTOR_NAME="liuliu"
XXL_JOB_PORT = 9999
XXL_JOB_TOKEN = ""